@@ -1,7 +1,6 @@
 package main
 
 import (
-	"github.com/fusor/openshift-migration-plugin/velero-plugins/migclusterrolebindings"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migdeployment"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migdeploymentconfig"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migimagestream"
@@ -10,9 +9,10 @@ import (
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migpod"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migpv"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migpvc"
-	"github.com/fusor/openshift-migration-plugin/velero-plugins/migrolebindings"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migsa"
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migscc"
+	"github.com/fusor/openshift-migration-plugin/velero-plugins/migrolebindings"
+	"github.com/fusor/openshift-migration-plugin/velero-plugins/migclusterrolebindings"
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/build"
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/buildconfig"
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/common"
@@ -28,9 +28,9 @@ import (
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/service"
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/serviceaccount"
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/statefulset"
-	veleroplugin "github.com/heptio/velero/pkg/plugin/framework"
 	apisecurity "github.com/openshift/api/security/v1"
 	"github.com/sirupsen/logrus"
+	veleroplugin "github.com/vmware-tanzu/velero/pkg/plugin/framework"
 )
 
 func main() {
