@@ -8,9 +8,9 @@ import (
 
 	"github.com/fusor/openshift-migration-plugin/velero-plugins/migcommon"
 	"github.com/fusor/openshift-velero-plugin/velero-plugins/common"
-	"github.com/heptio/velero/pkg/plugin/velero"
 	imagev1API "github.com/openshift/api/image/v1"
 	"github.com/sirupsen/logrus"
+	"github.com/vmware-tanzu/velero/pkg/plugin/velero"
 )
 
 // MyRestorePlugin is a restore item action plugin for Velero
@@ -105,14 +105,14 @@ func (p *RestorePlugin) Execute(input *velero.RestoreItemActionExecuteInput) (*v
 	return velero.NewRestoreItemActionExecuteOutput(input.Item).WithoutRestore(), nil
 }
 
-func copyImageRestore(src, dest string) (string, error) {
+func copyImageRestore(src, dest string) ([]byte, error) {
 	sourceCtx, err := migrationRegistrySystemContext()
 	if err != nil {
-		return "", err
+		return []byte{}, err
 	}
 	destinationCtx, err := internalRegistrySystemContext()
 	if err != nil {
-		return "", err
+		return []byte{}, err
 	}
 	return copyImage(src, dest, sourceCtx, destinationCtx)
 }
